Binary

Trait Binary 

1.6.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Binary for Access



impl Binary for AddressTaggingFeatureFlags



impl Binary for AllocateMode



impl Binary for AtRestFlags



impl Binary for BtiOptions

Source

impl Binary for Capabilities



impl Binary for ClockOpts



impl Binary for ConfigMutability



impl Binary for ConfigMutability



impl Binary for CpuFeatureFlags



impl Binary for DebugLogOpts



impl Binary for DynamicFlags



impl Binary for ExceptionChannelOptions

Source

impl Binary for FdEvents



impl Binary for FileSignal

Source

impl Binary for FileSystemFlags



impl Binary for Flags

Source

impl Binary for InotifyMask



impl Binary for IobAccess

Source

impl Binary for IptIpFlagsV4

Source

impl Binary for IptIpFlagsV6

Source

impl Binary for IptIpInverseFlags



impl Binary for JobCriticalOptions



impl Binary for MemoryStallKind



impl Binary for ModeType

Source

impl Binary for MountFlags

Source

impl Binary for MountpointFlags

Source

impl Binary for NfIpHooks

Source

impl Binary for NfNatRangeFlags



impl Binary for NodeAttributeFlags



impl Binary for NodeAttributesQuery



impl Binary for NodeProtocolKinds



impl Binary for OpenFlags

Source

impl Binary for starnix_uapi::open_flags::OpenFlags



impl Binary for Operations



impl Binary for PagerOptions



impl Binary for PagerWritebackBeginOptions

Source

impl Binary for PersonalityFlags



impl Binary for PortOptions



impl Binary for ProcessInfoFlags



impl Binary for ProcessOptions

Source

impl Binary for PtraceAccessMode



impl Binary for RaiseExceptionOptions

Source

impl Binary for ResolveFlags



impl Binary for ResourceFlag



impl Binary for ResourceKind



impl Binary for Rights

Source

impl Binary for SealFlags

Source

impl Binary for SecureBits



impl Binary for Signals



impl Binary for SocketOpts



impl Binary for SocketReadOpts



impl Binary for SocketWriteOpts



impl Binary for StreamOptions



impl Binary for StreamReadOptions



impl Binary for StreamWriteOptions



impl Binary for TransferDataOptions



impl Binary for UnlinkFlags

Source

impl Binary for UnmountFlags



impl Binary for VirtualMemoryFeatureFlags



impl Binary for VmarFlags



impl Binary for VmarFlagsExtended



impl Binary for VmoChildOptions



impl Binary for VmoFlags



impl Binary for VmoInfoFlags



impl Binary for VmoOptions



impl Binary for WaitAsyncOpts



impl Binary for WatchMask

Source

impl Binary for XtTcpInverseFlags

Source

impl Binary for XtUdpInverseFlags

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize



impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,



impl<'s, T> Binary for SliceVec<'s, T>
where T: Binary,



impl<A> Binary for ArrayVec<A>
where A: Array, <A as Array>::Item: Binary,



impl<A> Binary for TinyVec<A>
where A: Array, <A as Array>::Item: Binary,

Source

impl<O> Binary for I16<O>
where O: ByteOrder,

Source

impl<O> Binary for I32<O>
where O: ByteOrder,

Source

impl<O> Binary for I64<O>
where O: ByteOrder,

Source

impl<O> Binary for I128<O>
where O: ByteOrder,

Source

impl<O> Binary for Isize<O>
where O: ByteOrder,

Source

impl<O> Binary for U16<O>
where O: ByteOrder,

Source

impl<O> Binary for U32<O>
where O: ByteOrder,

Source

impl<O> Binary for U64<O>
where O: ByteOrder,

Source

impl<O> Binary for U128<O>
where O: ByteOrder,

Source

impl<O> Binary for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

1.28.0 · Source

impl<T> Binary for NonZero<T>

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for Wrapping<T>
where T: Binary,