Display

Trait Display 

1.6.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !



impl Display for Aborted

1.26.0 · Source

impl Display for AccessError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for AllocError

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar



impl Display for Availability



impl Display for AvailabilityList

Source

impl Display for bstr::bstr::BStr



impl Display for BStr

Available on crate feature alloc only.
Source

impl Display for BString

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for BigEndian



impl Display for BlockIndex



impl Display for BlockType

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError



impl Display for BorrowedChildName



impl Display for BorrowedSeparatedPath<'_>

Source

impl Display for BugRef

Source

impl Display for ByteStr

Source

impl Display for ByteString



impl Display for Bytes



impl Display for Canceled



impl Display for CapabilityTypeName

1.34.0 · Source

impl Display for CharTryFromError



impl Display for ChildName



impl Display for ChildRef



impl Display for CollectionAllocErr



impl Display for ConfigSingleValue



impl Display for ConfigValue



impl Display for ConfigVectorValue



impl Display for ContextError



impl Display for DeclField



impl Display for DeclType



impl Display for DecodeError



impl Display for DecodeSliceError

1.9.0 · Source

impl Display for DecodeUtf16Error



impl Display for DeliveryType



impl Display for DependencyNode

Source

impl Display for DeviceId

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>



impl Display for EmptyError



impl Display for EncodeSliceError



impl Display for EnterError

Source

impl Display for Errno

Source

impl Display for ErrnoCode

1.0.0 · Source

impl Display for std::io::error::Error

1.0.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::fmt::Error

Source

impl Display for serde_core::de::value::Error



impl Display for Error

Source

impl Display for serde_json::error::Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error

Source

impl Display for anyhow::Error



impl Display for Error



impl Display for Error

Source

impl Display for log::kv::error::Error

1.60.0 · Source

impl Display for ErrorKind



impl Display for ErrorList

Source

impl Display for ErrorStatus



impl Display for Errors

1.20.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::char::EscapeDebug

1.39.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::ascii::EscapeDefault

1.16.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::char::EscapeDefault

1.16.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::char::EscapeUnicode

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError



impl Display for ExposeSource



impl Display for ExposeTarget



impl Display for ExtendedMoniker

Source

impl Display for FileSystemFlags

Source

impl Display for FixedOffset



impl Display for FlyByteStr



impl Display for FlyStr

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

1.0.0 · Source

impl Display for alloc::string::FromUtf8Error

Source

impl Display for bstr::ext_vec::FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::slice::GetDisjointMutError



impl Display for GetDisjointMutError



impl Display for GetDisjointMutError



impl Display for GetTimezoneError



impl Display for HandleInfoError



impl Display for HandleType

1.34.0 · Source

impl Display for Infallible

1.7.0 · Source

impl Display for IntoStringError



impl Display for InvalidThreadAccess

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.0.0 · Source

impl Display for JoinPathsError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for Level

Source

impl Display for LevelFilter

Source

impl Display for LittleEndian

1.26.0 · Source

impl Display for Location<'_>



impl Display for Moniker



impl Display for MonikerError

Source

impl Display for MountFlags

Display trait implementation for the subset of flags that are stored with mounts or superblocks.

Source

impl Display for MountpointFlags

Source

impl Display for NaiveDate

The Display output of the naive date d is the same as d.format("%Y-%m-%d").

The string printed can be readily parsed via the parse method on str.

Example

use chrono::NaiveDate;

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(2015, 9, 5).unwrap()), "2015-09-05");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(0, 1, 1).unwrap()), "0000-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(9999, 12, 31).unwrap()), "9999-12-31");

ISO 8601 requires an explicit sign for years before 1 BCE or after 9999 CE.

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(-1, 1, 1).unwrap()), "-0001-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(10000, 12, 31).unwrap()), "+10000-12-31");
Source

impl Display for NaiveDateTime

The Display output of the naive date and time dt is the same as dt.format("%Y-%m-%d %H:%M:%S%.f").

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveDate;

let dt = NaiveDate::from_ymd_opt(2016, 11, 15).unwrap().and_hms_opt(7, 39, 24).unwrap();
assert_eq!(format!("{}", dt), "2016-11-15 07:39:24");

Leap seconds may also be used.

let dt =
    NaiveDate::from_ymd_opt(2015, 6, 30).unwrap().and_hms_milli_opt(23, 59, 59, 1_500).unwrap();
assert_eq!(format!("{}", dt), "2015-06-30 23:59:60.500");
Source

impl Display for NaiveTime

The Display output of the naive time t is the same as t.format("%H:%M:%S%.f").

The string printed can be readily parsed via the parse method on str.

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveTime;

assert_eq!(format!("{}", NaiveTime::from_hms_opt(23, 56, 4).unwrap()), "23:56:04");
assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(23, 56, 4, 12).unwrap()),
    "23:56:04.012"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_micro_opt(23, 56, 4, 1234).unwrap()),
    "23:56:04.001234"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_nano_opt(23, 56, 4, 123456).unwrap()),
    "23:56:04.000123456"
);

Leap seconds may also be used.

assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(6, 59, 59, 1_500).unwrap()),
    "06:59:60.500"
);


impl Display for Name



impl Display for Name



impl Display for NamespacePath

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for Number



impl Display for OfferSource



impl Display for OfferTarget

Source

impl Display for OutOfRange

Source

impl Display for OutOfRangeError

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>



impl Display for ParseAlphabetError

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

Source

impl Display for bitflags::parser::ParseError

Source

impl Display for chrono::format::ParseError



impl Display for ParseError



impl Display for ParseError

Source

impl Display for url::parser::ParseError



impl Display for ParseError

1.0.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::num::ParseFloatError

Source

impl Display for num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for ParseLevelError

Source

impl Display for ParseMonthError



impl Display for ParseNameError

Source

impl Display for ParseWeekdayError



impl Display for Path



impl Display for Range



impl Display for ReaderError

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError



impl Display for RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError



impl Display for RecvTimeoutError



impl Display for RelativePath

Source

impl Display for RoundingError



impl Display for SelectTimeoutError



impl Display for SendError



impl Display for SeparatedPath

Source

impl Display for SetLoggerError

Source

impl Display for Signal

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6



impl Display for SpawnError

Source

impl Display for Status



impl Display for StrContext



impl Display for StrContextValue

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

Source

impl Display for SyntaxViolation

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for TimeDelta

Source

impl Display for ToCasefold

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase



impl Display for TransportError

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

1.35.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::array::TryFromSliceError



impl Display for TryFromSliceError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError

1.57.0 · Source

impl Display for alloc::collections::TryReserveError



impl Display for TryReserveError



impl Display for TrySelectError

Source

impl Display for UnorderedKeyError



impl Display for Url

Source

impl Display for url::Url

Display the serialization of this URL.



impl Display for UrlScheme



impl Display for UseSource

Source

impl Display for UserAddress

Source

impl Display for UserCString

Source

impl Display for Utc

1.0.0 · Source

impl Display for starnix_uapi::arch32::__static_assertions::_core::str::Utf8Error

Source

impl Display for bstr::utf8::Utf8Error



impl Display for ValidationError

Source

impl Display for serde_json::value::Value

1.0.0 · Source

impl Display for VarError

Source

impl Display for Weekday

Source

impl Display for WeekdaySet

Print the collection as a slice-like list of weekdays.

Example

use chrono::Weekday::*;
assert_eq!("[]", WeekdaySet::EMPTY.to_string());
assert_eq!("[Mon]", WeekdaySet::single(Mon).to_string());
assert_eq!("[Mon, Fri, Sun]", WeekdaySet::from_array([Mon, Fri, Sun]).to_string());
Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize



impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>
where E: Engine,

Source

impl<'a, I, B> Display for DelayedFormat<I>
where I: Iterator<Item = B> + Clone, B: Borrow<Item<'a>>,

Available on crate feature alloc only.


impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,



impl<'a, K, V, S, A> Display for OccupiedError<'a, K, V, S, A>
where K: Debug, V: Debug, A: Allocator + Clone,



impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,



impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

Source

impl<'a> Display for EscapeBytes<'a>

1.34.0 · Source

impl<'a> Display for starnix_uapi::arch32::__static_assertions::_core::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for starnix_uapi::arch32::__static_assertions::_core::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for starnix_uapi::arch32::__static_assertions::_core::str::EscapeUnicode<'a>



impl<'a> Display for PercentEncode<'a>

Source

impl<'a> Display for Unexpected<'a>

Source

impl<'k> Display for Key<'k>



impl<'s, T> Display for SliceVec<'s, T>
where T: Display,

Source

impl<'v> Display for log::kv::value::Value<'v>

Source

impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.



impl<A> Display for ArrayVec<A>
where A: Array, <A as Array>::Item: Display,



impl<A> Display for TinyVec<A>
where A: Array, <A as Array>::Item: Display,

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,



impl<E> Display for ErrMode<E>
where E: Debug,

Source

impl<E> Display for Report<E>
where E: Error,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,



impl<I, C> Display for TreeError<I, C>
where I: Display, C: Display,

Available on crate feature std only.


impl<I, C> Display for TreeErrorContext<I, C>
where I: Display, C: Display,

Available on crate feature std only.


impl<I, E> Display for ParseError<I, E>
where I: AsBStr, E: Display,



impl<I, F> Display for FormatWith<'_, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,



impl<I, S> Display for Stateful<I, S>
where I: Display,



impl<I> Display for Decompositions<I>
where I: Iterator<Item = char> + Clone,



impl<I> Display for ExactlyOneError<I>
where I: Iterator,



impl<I> Display for InputError<I>
where I: Clone + Display,

The Display implementation allows the std::error::Error implementation



impl<I> Display for LocatingSlice<I>
where I: Display,



impl<I> Display for Partial<I>
where I: Display,



impl<I> Display for Recompositions<I>
where I: Iterator<Item = char> + Clone,



impl<I> Display for Replacements<I>
where I: Iterator<Item = char> + Clone,



impl<I> Display for TreeErrorBase<I>
where I: Display,

Available on crate feature std only.


impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K> Display for Property<K>
where K: AsRef<str>,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<S> Display for Host<S>
where S: AsRef<str>,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>



impl<T, E> Display for TryChunksError<T, E>
where E: Display,



impl<T, E> Display for TryReadyChunksError<T, E>
where E: Display,



impl<T, Item> Display for ReuniteError<T, Item>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,



impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for CapacityError<T>



impl<T> Display for Fragile<T>
where T: Display,

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for starnix_uapi::arch32::__static_assertions::_core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,



impl<T> Display for ReuniteError<T>

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,



impl<T> Display for SemiSticky<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>



impl<T> Display for SendError<T>

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>



impl<T> Display for SendTimeoutError<T>



impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,



impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,



impl<T> Display for Sticky<T>
where T: Display,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>



impl<T> Display for TrySendError<T>



impl<T> Display for TrySendError<T>

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

Source

impl<T> Display for UserRef<T>

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

Source

impl<Tz> Display for Date<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

Source

impl<Tz> Display for DateTime<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<const CAP: usize> Display for ArrayString<CAP>



impl<const N: usize> Display for BoundedBorrowedName<N>



impl<const N: usize> Display for BoundedName<N>