Octal

Trait Octal 

1.6.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Octal for Access



impl Octal for AddressTaggingFeatureFlags



impl Octal for AllocateMode



impl Octal for AtRestFlags



impl Octal for BtiOptions

Source

impl Octal for Capabilities



impl Octal for ClockOpts



impl Octal for ConfigMutability



impl Octal for ConfigMutability



impl Octal for CpuFeatureFlags



impl Octal for DebugLogOpts



impl Octal for DynamicFlags



impl Octal for ExceptionChannelOptions

Source

impl Octal for FdEvents



impl Octal for FileSignal

Source

impl Octal for FileSystemFlags



impl Octal for Flags

Source

impl Octal for InotifyMask



impl Octal for IobAccess

Source

impl Octal for IptIpFlagsV4

Source

impl Octal for IptIpFlagsV6

Source

impl Octal for IptIpInverseFlags



impl Octal for JobCriticalOptions



impl Octal for MemoryStallKind



impl Octal for ModeType

Source

impl Octal for MountFlags

Source

impl Octal for MountpointFlags

Source

impl Octal for NfIpHooks

Source

impl Octal for NfNatRangeFlags



impl Octal for NodeAttributeFlags



impl Octal for NodeAttributesQuery



impl Octal for NodeProtocolKinds



impl Octal for OpenFlags

Source

impl Octal for starnix_uapi::open_flags::OpenFlags



impl Octal for Operations



impl Octal for PagerOptions



impl Octal for PagerWritebackBeginOptions

Source

impl Octal for PersonalityFlags



impl Octal for PortOptions



impl Octal for ProcessInfoFlags



impl Octal for ProcessOptions

Source

impl Octal for PtraceAccessMode



impl Octal for RaiseExceptionOptions

Source

impl Octal for ResolveFlags



impl Octal for ResourceFlag



impl Octal for ResourceKind



impl Octal for Rights

Source

impl Octal for SealFlags

Source

impl Octal for SecureBits



impl Octal for Signals



impl Octal for SocketOpts



impl Octal for SocketReadOpts



impl Octal for SocketWriteOpts



impl Octal for StreamOptions



impl Octal for StreamReadOptions



impl Octal for StreamWriteOptions



impl Octal for TransferDataOptions



impl Octal for UnlinkFlags

Source

impl Octal for UnmountFlags



impl Octal for VirtualMemoryFeatureFlags



impl Octal for VmarFlags



impl Octal for VmarFlagsExtended



impl Octal for VmoChildOptions



impl Octal for VmoFlags



impl Octal for VmoInfoFlags



impl Octal for VmoOptions



impl Octal for WaitAsyncOpts



impl Octal for WatchMask

Source

impl Octal for XtTcpInverseFlags

Source

impl Octal for XtUdpInverseFlags

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize



impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,



impl<'s, T> Octal for SliceVec<'s, T>
where T: Octal,



impl<A> Octal for ArrayVec<A>
where A: Array, <A as Array>::Item: Octal,



impl<A> Octal for TinyVec<A>
where A: Array, <A as Array>::Item: Octal,

Source

impl<O> Octal for I16<O>
where O: ByteOrder,

Source

impl<O> Octal for I32<O>
where O: ByteOrder,

Source

impl<O> Octal for I64<O>
where O: ByteOrder,

Source

impl<O> Octal for I128<O>
where O: ByteOrder,

Source

impl<O> Octal for Isize<O>
where O: ByteOrder,

Source

impl<O> Octal for U16<O>
where O: ByteOrder,

Source

impl<O> Octal for U32<O>
where O: ByteOrder,

Source

impl<O> Octal for U64<O>
where O: ByteOrder,

Source

impl<O> Octal for U128<O>
where O: ByteOrder,

Source

impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

1.28.0 · Source

impl<T> Octal for NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for Wrapping<T>
where T: Octal,