pub struct MountpointFlags(/* private fields */);Expand description
Subset of MountFlags that allow the behaviours of different mountpoints to the same
underlying FileSystem to be independently configured.
Note that
Implementations
Sourceimpl MountpointFlags
impl MountpointFlags
pub const RDONLY: Self
pub const NOEXEC: Self
pub const NOSUID: Self
pub const NODEV: Self
pub const NOATIME: Self
pub const NODIRATIME: Self
pub const RELATIME: Self
pub const STORED_ON_MOUNT: Self
pub const STRICTATIME: Self
pub const REC: Self
Sourcepub const ATIME_MODE_FLAGS: Self
pub const ATIME_MODE_FLAGS: Self
Flags used to control how file access times are managed. Note that STRICTATIME is only used by callers to specify that all other bits should be cleared; it is never stored.
pub const ATIME_FLAGS: Self
Sourceimpl MountpointFlags
impl MountpointFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MountpointFlags
impl MountpointFlags
Sourcepub const fn iter(&self) -> Iter<MountpointFlags> ⓘ
pub const fn iter(&self) -> Iter<MountpointFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MountpointFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<MountpointFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl MountpointFlags
impl MountpointFlags
Sourcepub fn default_atime_from(&mut self, existing: MountpointFlags)
pub fn default_atime_from(&mut self, existing: MountpointFlags)
Ensures that self has an access-time flag set, copying the flag value from existing if
no flag is currently set.
This is used both to apply the kernel default MS_RELATIME if no other access-time flag is
passed to mount(), and to preserve existing access-time flags when re-mounting, unless the
MS_STRICTATIME flag is explicitly passed.