SigSet

Struct SigSet 

#[repr(transparent)]
pub struct SigSet(pub c_ulong);
POSIX defines sigset_t as either a numeric or structure type (so the number of signals can exceed the bits in a machine word). The programmer is supposed to modify this bitfield using sigaddset(), etc. rather than setting bits directly so client code can be agnostic to the definition.

  • On x64, sigset_t is a typedef for “unsigned long”.
  • On ARM64, sigset_t is a structure containing one “unsigned long” member.

To keep the Starnix code agnostic to the definition, this SigSet type provides a wrapper with a uniform interface for the things we need.

The layout of this object is designed to be identical to the layout of the current architecture’s sigset_t type so UserRef can be used for system calls.

Tuple Fields

0: c_ulong

Implementations

Source

impl SigSet

pub fn has_signal(&self, signal: Signal) -> bool

Returns whether this signal set contains the given signal.

pub fn intersects(&self, other: &Self) -> bool

Returns whether this signal set has any signals in common with another.